# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`simp_ds389::instances::accounts`](#simp_ds389instancesaccounts): Create a 389ds instance with a common organizational LDIF for user accounts

## Classes

### <a name="simp_ds389instancesaccounts"></a>`simp_ds389::instances::accounts`

Create a 389ds instance with a common organizational LDIF for user accounts

#### Parameters

The following parameters are available in the `simp_ds389::instances::accounts` class:

* [`instance_name`](#instance_name)
* [`base_dn`](#base_dn)
* [`root_dn`](#root_dn)
* [`root_pw`](#root_pw)
* [`bind_dn`](#bind_dn)
* [`bind_pw`](#bind_pw)
* [`listen_address`](#listen_address)
* [`enable_tls`](#enable_tls)
* [`firewall`](#firewall)
* [`trusted_nets`](#trusted_nets)
* [`port`](#port)
* [`secure_port`](#secure_port)
* [`tls_params`](#tls_params)
* [`instance_params`](#instance_params)
* [`password_policy`](#password_policy)
* [`users_group_id`](#users_group_id)
* [`administrators_group_id`](#administrators_group_id)

##### <a name="instance_name"></a>`instance_name`

Data type: `String[1]`

The unique name of the instance.

Default value: `'accounts'`

##### <a name="base_dn"></a>`base_dn`

Data type: `String[2]`

The base Distinguished Name of the directory server.

Default value: `simplib::lookup('simp_options::ldap::base_dn', { 'default_value' => sprintf(simplib::ldap::domain_to_dn($facts['domain'], true)) })`

##### <a name="root_dn"></a>`root_dn`

Data type: `String[2]`

The default administrator Distinguished Name for the directory server.

* NOTE: To work around certain application bugs, items with spaces may not
  be used in this field.

Default value: `'cn=Directory_Manager'`

##### <a name="root_pw"></a>`root_pw`

Data type: `String[2]`

The password for the the ``$root_dn``.

* NOTE: To work around certain application bugs, items with spaces may not
  be used in this field.

Default value: `simplib::passgen('simp_ds389-rootdn_accounts', { 'length' => 64, 'complexity' => 0 })`

##### <a name="bind_dn"></a>`bind_dn`

Data type: `String[2]`

The bind Distinguished Name of the directory server.

Default value: `simplib::lookup('simp_options::ldap::bind_dn', { 'default_value'   => "cn=hostAuth,ou=Hosts,${base_dn}" })`

##### <a name="bind_pw"></a>`bind_pw`

Data type: `String[1]`

The bind password.

Default value: `simplib::lookup('simp_options::ldap::bind_pw', { 'default_value' => simplib::passgen("ds389_${instance_name}_bindpw", {'length' => 64})})`

##### <a name="listen_address"></a>`listen_address`

Data type: `Simplib::IP`

The IP address upon which to listen.

Default value: `'0.0.0.0'`

##### <a name="enable_tls"></a>`enable_tls`

Data type: `Variant[Boolean, Enum['simp']]`

Whether to configure the server to use TLS and also how to copy the
pki certificates.

* simp => Will enable TLS and copy the certificates out from the
          puppetserver.
* true => Will enable TLS and copy the certificates from a local
          directory on the server.
* false => Will not enable TLS

Default value: `simplib::lookup('simp_options::pki', { 'default_value' => false })`

##### <a name="firewall"></a>`firewall`

Data type: `Boolean`

Whether to configure access through the firewall.

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false })`

##### <a name="trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Which networks to all access through the firewall.

Default value: `simplib::lookup('simp_options::trusted_nets', {'default_value' => ['127.0.0.1/32'] })`

##### <a name="port"></a>`port`

Data type: `Simplib::Port`

The port upon which to accept normal/STARTTLS connections

Default value: `389`

##### <a name="secure_port"></a>`secure_port`

Data type: `Simplib::Port`

The port upon which to accept LDAPS connections.

Default value: `636`

##### <a name="tls_params"></a>`tls_params`

Data type: `Hash`

Parameters to pass to the TLS module.

Default value: `{}`

##### <a name="instance_params"></a>`instance_params`

Data type: `Hash`

Any other arguments that you wish to pass through directly to the
`ds389::instance` Defined Type.

Default value: `{}`

##### <a name="password_policy"></a>`password_policy`

Data type: `Ds389::ConfigItem`

Settings for the password policy.  The defaults in the module data
are set to meet most compliance standards.

##### <a name="users_group_id"></a>`users_group_id`

Data type: `Integer[1]`

The group ID of the "users" group created in the install.

Default value: `100`

##### <a name="administrators_group_id"></a>`administrators_group_id`

Data type: `Integer[500]`

The group ID of the "administrators" group created in the install.
The pupmod-simp-simp module configures permissions on systems using
simp with the admin.pp manifest.

Default value: `700`

